@@ -3,7 +3,7 @@
 # see the repack.stub for how to use
 
 # Copyright 2009, Ryan Niebur <ryan@debian.org>
-# Copyright 2009-2011, gregor herrmann <gregoa@debian.org>
+# Copyright 2009-2023, gregor herrmann <gregoa@debian.org>
 # License: Artistic or GPL-1+
 
 # TODO: provide example watch files and repack.locals
@@ -20,7 +20,7 @@
 set -e
 set -u
 
-. "$DPT__SCRIPTS/lib/dpt-lib.sh"
+. "${DPT__SCRIPTS:-/usr/share/pkg-perl-tools}/lib/dpt-lib.sh"
 
 usage() {
     echo "Usage: repack.sh --upstream-version <ver> <downloaded file>"
@@ -211,7 +211,7 @@ F<MANIFEST> file, if present.
 
 Copyright 2009, Ryan Niebur L<ryan@debian.org>
 
-Copyright 2009-2011, gregor herrmann L<gregoa@debian.org>
+Copyright 2009-2023, gregor herrmann L<gregoa@debian.org>
 
 This program is free software and can be distributed under the same terms as
 Perl.
